// src/index.ts
import { createRequire } from "node:module";
import { createSyncFn } from "synckit";
var RE_HIGHLIGHT = /(?<=\/\*|#|\/\/|<%#)\s*shada:highlight\b/;
var RE_DIFF_ADD = /(?<=\/\*|#|\/\/|<%#)\s*shada:add\b/;
var RE_DIFF_REMOVE = /(?<=\/\*|#|\/\/|<%#)\s*shada:remove\b/;
var RE_FOCUS = /(?<=\/\*|#|\/\/|<%#)\s*shada:focus\b/;
function attrsLineOptions(attrs) {
  let lineNumbers = false;
  attrs.replace(/[{}]/g, "").split(",").forEach((v) => {
    const [key, value] = v.split(":");
    if (key === "lineNumbers" && (value === "true" || value === "1"))
      lineNumbers = true;
  });
  return { lineNumbers };
}
function buidLineOptions(tokens) {
  const lineOptions = [];
  let isDiff = false;
  let isFocus = false;
  for (let lineIndex = 0; lineIndex < tokens.length; lineIndex++) {
    const line = tokens[lineIndex];
    for (let tokenIndex = 0; tokenIndex < line.length; tokenIndex++) {
      const token = line[tokenIndex];
      if (RE_HIGHLIGHT.exec(token.content)) {
        lineOptions.push({
          line: lineIndex + 1,
          classes: ["line-highlight"]
        });
      }
      if (RE_DIFF_ADD.exec(token.content)) {
        lineOptions.push({
          line: lineIndex + 1,
          classes: ["line-add"]
        });
        isDiff = true;
      }
      if (RE_DIFF_REMOVE.exec(token.content)) {
        lineOptions.push({
          line: lineIndex + 1,
          classes: ["line-remove"]
        });
        isDiff = true;
      }
      if (RE_FOCUS.exec(token.content)) {
        lineOptions.push({
          line: lineIndex + 1,
          classes: ["line-focus"]
        });
        isFocus = true;
      }
    }
  }
  return { lineOptions, isDiff, isFocus };
}
var ShadaIt = (markdownit, options = {}) => {
  const _highlighter = options.highlighter;
  const themes = [];
  if (!options.theme) {
    themes.push("nord");
  } else if (typeof options.theme === "string") {
    themes.push(options.theme);
  }
  let syncRun;
  if (!_highlighter) {
    const require2 = createRequire(import.meta.url);
    syncRun = createSyncFn(require2.resolve("./worker"));
    syncRun("getHighlighter", { themes });
  }
  const tokenizeCode = (code, lang) => {
    if (_highlighter)
      return _highlighter.codeToThemedTokens(code, lang);
    return syncRun("codeToThemedTokens", {
      code,
      lang
    });
  };
  const renderToHtml = (tokens, theme, lineOptions, attrsOptions) => {
    return syncRun("renderToHtml", {
      tokens,
      theme,
      lineOptions,
      attrsOptions
    });
  };
  markdownit.options.highlight = (code, lang = "text", attrs) => {
    const tokens = tokenizeCode(code, lang);
    const { lineOptions, isDiff, isFocus } = buidLineOptions(tokens);
    const attrsOptions = { ...attrsLineOptions(attrs), isDiff, isFocus };
    return renderToHtml(tokens, themes.at(0), lineOptions, attrsOptions);
  };
};
var src_default = ShadaIt;

export {
  RE_HIGHLIGHT,
  RE_DIFF_ADD,
  RE_DIFF_REMOVE,
  RE_FOCUS,
  src_default
};
